/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file translation.h
\brief Interface for translation instances \see Translation

\author Bartosz Szatkowski <bulislaw@linux.com>
*/

#ifndef TRANSLATION_H
#define TRANSLATION_H

#include <QString>
#include <QMetaType>
#include <QDebug>

class CommonDictInterface;


/*! Translation is kind of GoF proxy, it stores key:translation pair and
  provides it in a lazy way -> key is available always, but translation is fetched
  as late as possible*/
class Translation {
  public:
    Translation  () { _bookmark = 0;}
    virtual ~Translation () {}

    //! \return word to be translated
    virtual QString key() const = 0;
 
    //! compares two translations by key
    bool operator==(Translation* translation) {
        return this->key()==translation->key();
    }

    //! \return parsed raw format into xml
    virtual QString toXml() const = 0;

    //! \return whether given translation is taken from bookmarks
    virtual int isBookmark() const {
        return _bookmark;
   }

   //! \param b if true then translation is from bookmarks
   void setBookmark(bool b) {
       _bookmark = b;
   }

    //! \returns corresponding dict object
   virtual uint dict() const {return 0;}

 protected:
 //! indicates whether this translation is in bookmark
    int _bookmark;

};

Q_DECLARE_METATYPE(Translation*);
Q_DECLARE_METATYPE(QList<Translation*>);

#endif
