#include "DictManagerModel.h"

DictManagerModel::DictManagerModel(QHash<CommonDictInterface *, bool> dictionaries, QObject *parent) :
    QAbstractListModel(parent)
{
    QHash<int, QByteArray> roles;
    roles[NameRole] = "name";
    roles[IconPathRole] = "iconPath";
    roles[IsSelectedRole] = "isSelected";
    roles[NumberRole] = "number";
    setRoleNames(roles);

    setDictionaries(dictionaries);

    connect(this, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SIGNAL(itemChanged()));
}

int DictManagerModel::rowCount(const QModelIndex &parent) const
{
    return _dictList.count();
}

void DictManagerModel::setDictionaries(QHash<CommonDictInterface *, bool> dictionaries)
{
    QHashIterator<CommonDictInterface *, bool> i(dictionaries);
    while (i.hasNext()) {
        i.next();
        addDictionary(i.key(), i.value());
    }
}

void DictManagerModel::clear()
{
    beginRemoveRows(QModelIndex(), 0, rowCount());
    _dictionaries.clear();
    _dictList.clear();
    endRemoveRows();
    emit dataChanged(QModelIndex(), QModelIndex());
}

QVariant DictManagerModel::data(const QModelIndex & index, int role) const
{
    if (index.row() < 0 || index.row() > _dictList.count())
        return QVariant();

    CommonDictInterface* dictionary = _dictList[index.row()];
    if (role == NameRole)
    {
        QString name;
        if (dictionary->type() == "stardict") {
            name = dictionary->name() + " (" + dictionary->type() + ")";
        }
        else {
            name = dictionary->langFrom() + " - " + dictionary->langTo() +
                   " (" + dictionary->type() + " " +
                   dictionary->name() + ")";
        }
        return name;
    }
    if (role == NumberRole){
        return index.row();
    }
    if (role == IconPathRole){
        return dictionary->iconPath();
    }
    if (role == IsSelectedRole){
        return _dictionaries[dictionary];
    }
    return QVariant();
}

bool DictManagerModel::setData(const QModelIndex &index, const QVariant &value, int role)
{
    int res = setDataPriv(index.row(), value, role);
    if (res == 0)
        return false;
    if (res > 0)
        return true;
    return true;
}

int DictManagerModel::setDataPriv(int index, const QVariant &value, int role)
{
    if (index < 0 || index > _dictList.count())
        return 0;

    CommonDictInterface* dictionary = _dictList[index];
    if (role == NameRole)
        return 1;
    if (role == NumberRole)
        return 1;
    if (role == IconPathRole)
        return 1;
    if (role == IsSelectedRole)
    {
        if (value.type() == QVariant::Bool)
        {
            _dictionaries[dictionary] = value.toBool();
//            if (index == _dictList.count())
//                emit dataChanged(this->index(index-1), this->index(index));
            emit dataChanged(this->index(0), this->index(_dictList.count() - 1));
            return 2;
        }
        else
        {
            return 0;
        }
    }
    return 0;
}

void DictManagerModel::setModelProperty(int index, const QVariant value, QString role)
{
    if (role.contains("isSelected"))
    {
        setDataPriv(index, value, IsSelectedRole);
    }

}

Qt::ItemFlags DictManagerModel::flags(const QModelIndex &index) const
{
    Qt::ItemFlags fl = QAbstractItemModel::flags(index);
    qDebug("lol1");
    return (fl | Qt::ItemIsEditable);
}

void DictManagerModel::addDictionary(CommonDictInterface *dictionary, bool isActive)
{
    beginInsertRows(QModelIndex(), rowCount(), rowCount());
    _dictionaries.insert(dictionary, isActive);
    _dictList << dictionary;
    endInsertRows();
}

QHash<CommonDictInterface*, bool> DictManagerModel::dictionaries()
{
    return _dictionaries;
}

QList<CommonDictInterface*> DictManagerModel::dictList()
{
    return _dictList;
}
