/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file HistoryListDialog.cpp
    \brief Implements history list dialog

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include "HistoryListDialog.h"

HistoryListDialog::HistoryListDialog(QStringList words, QWidget *parent):
        QDialog(parent)
{
    verticalLayout = new QVBoxLayout(this);
    setLayout(verticalLayout);

    #ifndef Q_WS_MAEMO_5
        setWindowFlags(Qt::Popup);
        QLabel* title = new QLabel(tr("History"));
        verticalLayout->addWidget(title,0, Qt::AlignCenter);
    #endif

    oryginalList = words;

    historyListWidget = new QListWidget(this);
    verticalLayout->addWidget(historyListWidget);

    for(int i=0; i<words.count(); i++) {
        QListWidgetItem* item = new QListWidgetItem(
                QString::number(i+1) + ". " + words[i]);
        historyListWidget->addItem(item);
    }

     setModal(true);

     setWindowTitle(tr("History"));

     setMinimumHeight(300);

     connect(historyListWidget, SIGNAL(activated(QModelIndex)),
             this, SLOT(itemClicked(QModelIndex)));
}


void HistoryListDialog::itemClicked(QModelIndex index) {
    _selectedWord = oryginalList[index.row()];
    _selectedRow = index.row();
    accept();
}


QString HistoryListDialog::selectedWord() {
    return _selectedWord;
}

int HistoryListDialog::selectedRow() {
    return _selectedRow;
}

int HistoryListDialog::exec() {
    historyListWidget->setFocus();
    QDialog::exec();
}
