/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*! \file MenuWidget.h
    \brief Displays custom menu with tab widget containing all submenus.

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#ifndef MENUWIDGET_H
#define MENUWIDGET_H

#include <QWidgetAction>
#include "MenuTabWidget.h"

/*! Displays custom menu with tab widget containing all submenus.
  Each submenu is simply QWidget.
*/
class MenuWidget : public QWidgetAction {
    Q_OBJECT
public:
    explicit MenuWidget(QWidget *parent = 0);
    virtual ~MenuWidget();

    /*!
        Adds new submenu to menu. It is possible to have many submenus with the
        same title.
        \param title Name of new submenu which will be displayed in submenu tab.
        \param widget Widget of the submenu.
     */
    void addSubMenu(QString title, QWidget* widget);

    /*!
        Removes submenu from menu. It will remove first menu with passed title.
        /param title Name of submenu which will be removed.
    */
    void removeSubMenu(QString title);

Q_SIGNALS:
    void setApplicationMenu(QWidget*);

public Q_SLOTS:
    /*!
      Hides menu
      */
    void hideMenu();

    void showMenu();

protected:
    QWidget* createWidget(QWidget *parent);

private:
    MenuTabWidget* tabWidget;
    QWidget* applicationMenu;
};

#endif // MENUWIDGET_H
