/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file TranslationView.cpp
    \brief Web view with translations

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include <QtGui>
#include "TranslationView.h"
#include "TranslationWidget.h"



TranslationView::TranslationView(QWidget *parent) : QWebView(parent) {

#ifndef Q_WS_MAEMO_5

    view= new QDeclarativeView();
    view->setSource(QUrl("src/mdictionary/qml/TranslationView.qml"));
    view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
    view->setAlignment(Qt::AlignCenter);
    view->show();

    mainLayout = new QVBoxLayout;
    mainLayout->addWidget(view);
    setLayout(mainLayout);

    QGraphicsObject *rootObject = view->rootObject();

    connect(this, SIGNAL(setUrl(QVariant)),
           rootObject, SLOT(setUrl(QVariant)));
#else

    realParent = qobject_cast<TranslationWidget*>(parent);
    searchSelectedAction = new QAction(tr("Search"), this);
    copySelectedAction = new QAction(tr("Copy"), this);
    selectAllAction = new QAction(tr("Select All"), this);
    setAcceptDrops(false);

    #ifdef Q_WS_MAEMO_5
        installEventFilter(this);
        property("kineticScroller").value<QAbstractKineticScroller*>()->
                setEnabled(true);
    #endif


    connect(searchSelectedAction, SIGNAL(triggered()),
            this, SIGNAL(search()));
    connect(page(), SIGNAL(selectionChanged()), this, SLOT(selection()));

#endif
}

void TranslationView::setHtml(QString htmlString){
    QString url = QDir::homePath() + "/.mdictionary/" + "html.html";
    QFile file(url);
    if(file.open(QIODevice::WriteOnly | QIODevice::Text)){
        QByteArray array = htmlString.toUtf8();
        file.write(array);
        file.close();
        emit setUrl(url);
    }
}

void TranslationView::wheelEvent(QWheelEvent *e) {
#ifndef Q_WS_MAEMO_5
#else
    if(e->modifiers() & Qt::ControlModifier) {
        if(e->delta()>0) {
            zoomIn();
        }
        else {
            zoomOut();
        }
        e->ignore();
    }
    else {
        QWebView::wheelEvent(e);
    }
#endif
}

bool TranslationView::eventFilter(QObject *, QEvent *e) {
#ifndef Q_WS_MAEMO_5
#else
    switch (e->type()) {
    case QEvent::MouseButtonPress:
        if (static_cast<QMouseEvent *>(e)->button() == Qt::LeftButton)
            mousePressed = true;
        break;
    case QEvent::MouseButtonRelease:
        if (static_cast<QMouseEvent *>(e)->button() == Qt::LeftButton)
            mousePressed = false;
        break;
    case QEvent::MouseMove:
        if (mousePressed)
            return true;
    default:
        break;
    }
    return false;
#endif
}


void TranslationView::contextMenuEvent(QContextMenuEvent *e) {
#ifndef Q_WS_MAEMO_5
#else
    QMenu *menu = new QMenu;
    if(selectedText().isEmpty())
        searchSelectedAction->setEnabled(false);
    else
        searchSelectedAction->setEnabled(true);

    menu->addAction(searchSelectedAction);
    menu->addSeparator();
    menu->addAction(pageAction(QWebPage::Copy));
    menu->addAction(pageAction(QWebPage::SelectAll));

    menu->exec(e->globalPos());
    delete menu;

    e->ignore();
#endif
}


void TranslationView::zoomIn() {
#ifndef Q_WS_MAEMO_5
#else
    if(zoomFactor() >= 3)
        return;
    setZoomFactor(zoomFactor()*1.05);
    realParent->updateZoom(zoomFactor());
#endif
}

void TranslationView::zoomOut() {
#ifndef Q_WS_MAEMO_5
#else
    if(zoomFactor() <= 0.5)
        return;
    setZoomFactor(zoomFactor()*0.95);
    realParent->updateZoom(zoomFactor());
#endif
}

void TranslationView::copy() {
#ifndef Q_WS_MAEMO_5
#else
      pageAction(QWebPage::Copy)->trigger();
#endif
}

void TranslationView::selection() {
#ifndef Q_WS_MAEMO_5
#else
    if(selectedText().size())
        Q_EMIT copyAvailable(true);
    else
        Q_EMIT copyAvailable(false);
#endif
}


void TranslationView::selectAll() {
#ifndef Q_WS_MAEMO_5
#else
    pageAction(QWebPage::SelectAll)->trigger();
#endif
}



