/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file UncompressedReader.h
    \brief Class implementing StarDictReader interface and handling
  reading from uncompressed files

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
 */

#ifndef UNCOMPRESSEDREADER_H
#define UNCOMPRESSEDREADER_H

#include <QObject>
#include <QFile>
#include <QDataStream>
#include <QString>
#include "StarDictReader.h"


/*!
  Class implementing StarDictReader interface and handling
  reading from uncompressed files
*/
class UncompressedReader : public StarDictReader
{
    Q_OBJECT
public:
    UncompressedReader(QObject *parent = 0);

    //! Creates new reader and open file with passed filename
    UncompressedReader(QString filename, QObject *parent = 0);

    //! Destructs object and closing file
    ~UncompressedReader();

    /*!
        Reads translations text from file
        \param offset 64-bit offset of translation in file, readed
        from idx file
        \param len length of translation, readed from idx file too
    */
    QByteArray readString(qint64 offset, qint32 len);

    /*!
        Reads 32-bits integer value from file and convert it from
        BigEndian to Little Endian
    */
    qint32 readInt32BigEndian();

    /*!
        Reads 64-bits integer value from file and convert it from
        BigEndian to Little Endian
    */
    qint64 readInt64BigEndian();

    /*!
        Reads single string from file, end of string is marked as '\0'
        in file.
    */
    QString readKeyword();

    //! Closing file;
    void close();

protected:
    /*!
        Opens file
        \returns true if file is opened or false otherwise
    */
    bool open(QString file);

    //! Reads single char from compressed.
    QChar readChar();

private:
    QFile _file;
    QDataStream _stream;
};

#endif // UNCOMPRESSEDREADER_H
