/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file XdxfLoadDialog.cpp
*/
//Created by Mateusz Półrola

#include "XdxfLoadDialog.h"

XdxfLoadDialog::XdxfLoadDialog(QWidget *parent) :
    QDialog(parent) {
    verticalLayout = new QVBoxLayout;
    setLayout(verticalLayout);

    setWindowTitle(tr("Add new XDXF dictionary"));

    browseLayout = new QVBoxLayout;

    browseButton =  new QPushButton(tr("Browse"));
    browseLabel = new QLabel(tr("Dictionary file: not selected"));
    //browseLabel->setWordWrap(true);
    browseLabel->setMargin(5);

    browseLayout->addWidget(browseLabel, 0, Qt::AlignLeft);
    browseLayout->addWidget(browseButton);

    verticalLayout->addLayout(browseLayout);

    cacheLayout = new QHBoxLayout;
    verticalLayout->addLayout(cacheLayout);
    accentsCheckBox = new QCheckBox(tr("Strip accents \n(searching takes more "
                 "time, but spelling don't have to be exact)"));
    verticalLayout->addWidget(accentsCheckBox);

    cacheCheckBox = new QCheckBox(tr("Optimize for quicker searches (may take some time)"),this);
    cacheCheckBox->setChecked(true);
    cacheLayout->addWidget(cacheCheckBox);

    addButton = new QPushButton(tr("Add"));

    verticalLayout->addWidget(addButton);

    setModal(true);

    connect(browseButton, SIGNAL(clicked()),
            this, SLOT(selectFile()));

    connect(addButton, SIGNAL(clicked()),
            this, SLOT(addDictionary()));

    connect(cacheCheckBox, SIGNAL(toggled(bool)),
            SLOT(setGenerateCache(bool)));

    connect(accentsCheckBox, SIGNAL(clicked(bool)), SLOT(setAccents(bool)));
    lastAccents = accentsCheckBox->isChecked();
    _dicitonaryFilePath = QString();
}



void XdxfLoadDialog::setAccents(bool state) {
    lastAccents = state;
}



void XdxfLoadDialog::selectFile() {
    QString fileName = QFileDialog::getOpenFileName(this,
                                     tr("Select dictionary file"),
                                     "",
                                     tr("XDXF Files (*.xdxf)"),
                                     0,
                                     0);

    if (!fileName.isEmpty()) {
        browseLabel->setText(tr("Dictionary file: %1").arg(fileName));
        _dicitonaryFilePath = fileName;
    }repaint(rect());
    resize(size());
}

void XdxfLoadDialog::addDictionary() {
    _generateCache = cacheCheckBox->isChecked();
    if(!_dicitonaryFilePath.isEmpty()) {
        accept();
    }
    else {
        reject();
    }
}

QString XdxfLoadDialog::dicitonaryFilePath() {
    return _dicitonaryFilePath;
}

bool XdxfLoadDialog::generateCache() {
    return _generateCache;
}

void XdxfLoadDialog::setGenerateCache(bool generate) {
    _generateCache = generate;

    if(generate)
        accentsCheckBox->setChecked(true);
    else
        accentsCheckBox->setChecked(lastAccents);

    accentsCheckBox->setEnabled(!generate);
}

Settings* XdxfLoadDialog::getSettings(QWidget *parent) {
    XdxfLoadDialog loadDialog(parent);
    Settings* settings = new Settings;

    if(loadDialog.exec()==QDialog::Accepted) {
        settings->setValue("path", loadDialog.dicitonaryFilePath());
        if(loadDialog.generateCache()) {
            settings->setValue("generateCache", "true");
        }
        else {
            settings->setValue("generateCache", "false");
        }
        if(loadDialog.accentsCheckBox->isChecked())
            settings->setValue("strip_accents", "true");
        else
            settings->setValue("strip_accents", "false");


        return settings;
    }

    return 0;
}


